@@ -2,6 +2,7 @@ import io
 import os
 import posixpath
 import re
+import time
 from ebrains_drive.utils import querystr
 
 # Note: only files and dirs with contents is assigned an ID; else their ID is set to all zeros
@@ -189,6 +190,51 @@ class SeafDir(_SeafDirentBase):
 
         # fetch and return created directory object
         return SeafDir(self.repo, path, ZERO_OBJ_ID, "dir")
+    
+    def download(self, name=None):
+        """Download the entire contents of a directory as a zip file
+
+        :param:name The name of the downloaded zip file. 
+            If None, the name of the directory (or repo name in case of root directory) would be used.
+        
+        Returns a dict in following format:
+        {'zipped': NUM, 'total': NUM, 'failed': NUM, 'failed_reason': '', 'canceled': NUM}
+        """
+        download_token = self._get_download_token()
+        url = '/api/v2.1/query-zip-progress/?token=%s' % (download_token)
+        wait = True
+        while wait:
+            resp = self.client.get(url).json()
+            if resp["total"] == resp["zipped"] + resp["failed"] + resp["canceled"]:
+                wait = False
+            else:
+                time.sleep(1)
+        if resp["total"] != resp["zipped"]:
+            raise Exception(resp["failed_reason"]) 
+        url = '%s/seafhttp/zip/%s' % (self.client.server, download_token)
+        zip_data = self.client.get(url).content
+        if name:
+            name = name if name.endswith(".zip") else name + ".zip"
+        else:
+            name = '%s.zip' % (self.repo.name) if (self.path == "/") else '%s.zip' % (self.path.split("/")[-1])
+        with open(name, 'wb') as f:
+            f.write(zip_data)
+        return resp
+
+    def _get_download_token(self):
+        if self.path == "/":
+            parent_dir = "/"
+            dirents = [item.name for item in self.ls()]
+        else:
+            parent_dir = "/".join(self.path.split("/")[0:-1]) or "/"
+            dirents = self.path.split("/")[-1]
+        url = '/api/v2.1/repos/%s/zip-task/' % (self.repo.id)
+        data = {
+            'parent_dir': parent_dir,
+            'dirents': dirents,
+        }
+        resp = self.client.post(url, data=data).json()
+        return resp["zip_token"]
 
     def upload(self, fileobj, filename):
         """Upload a file to this folder.
